#ifndef WIDGET_H
#define WIDGET_H

#include <QtOpenGL/QGLWidget>
#include <vector>
#include "vector.h"

class GLWidget : public QGLWidget
{
    Q_OBJECT

public:
    GLWidget(QWidget *parent = 0);
    ~GLWidget();

public slots:
    void changeLoftShape(int value);

signals:
    void rotatedX(int);
    void rotatedY(int);
protected:
    void initializeGL();
    void resizeGL(int w, int h);
    void paintGL();
    void mouseMoveEvent(QMouseEvent *event);
    void mousePressEvent(QMouseEvent *);
private:
    int xRot;
    int yRot;
    QPoint last;
    std::vector<Vector> loftPath;
    std::vector<Vector> loftShape;
    float* verticesLoft;
    float* normalsLoft; //for correct lighting we need to calculate the normals for each primitive
    float* verticesCaps;
    float* normalsCaps;
    int numVerticesLoft;
    int numVerticesCaps;
    void calculateVertexPositions();
    void calculateLoftQuadArray(const std::vector<Vector>& transformedPoints);
    void calculateCapsTriangleArray(const std::vector<Vector>& transformedPoints);

};

#endif // WIDGET_H
